# django-environs

**django-environs** is a cli tool for bootstraping Django projects with
[environs](https://github.com/sloria/environs) settings.

## Install
`pip install django-environs`

django-environs requires Python 3.6 or higher.

## Usage
`django-environs startproject example`

See [settings.py](https://github.com/jwygoda/django-environs/blob/master/example/example/settings.py)
for some example output.

[environs[django]](https://github.com/sloria/environs) is required to run django-environs
bootstraped project.
